summaryrefslogtreecommitdiffstats
path: root/ksvg/impl/SVGLangSpaceImpl.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commitda4be7880ff1de6415ab6256afd2514e64f5fa2e (patch)
tree0862c14883af0435b012f6f592221fc167ed7d91 /ksvg/impl/SVGLangSpaceImpl.cc
parentd0a269b9b0361bf71c5dd5787be0839f9dcace8c (diff)
downloadtdegraphics-da4be7880ff1de6415ab6256afd2514e64f5fa2e.tar.gz
tdegraphics-da4be7880ff1de6415ab6256afd2514e64f5fa2e.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksvg/impl/SVGLangSpaceImpl.cc')
-rw-r--r--ksvg/impl/SVGLangSpaceImpl.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/ksvg/impl/SVGLangSpaceImpl.cc b/ksvg/impl/SVGLangSpaceImpl.cc
index 5a55ef15..edc35a4d 100644
--- a/ksvg/impl/SVGLangSpaceImpl.cc
+++ b/ksvg/impl/SVGLangSpaceImpl.cc
@@ -67,19 +67,19 @@ TQString SVGLangSpaceImpl::handleText(const TQString &data) const
{
// Spec: What to do here?
// It will convert all newline and tab characters into space characters
- result.tqreplace("\n\r", TQString(" "));
- result.tqreplace("\r\n", TQString(" "));
- result.tqreplace('\t', ' ');
+ result.replace("\n\r", TQString(" "));
+ result.replace("\r\n", TQString(" "));
+ result.replace('\t', ' ');
}
else if(xmlspace() == "default")
{
// Spec: What to do here?
// First, it will remove all newline characters (tqreplace)
// Then it will convert all tab characters into space characters (simplifyWhiteSpace)
// Then, it will strip off all leading and trailing space characters (stripWhiteSpace)
// Then, all contiguous space characters will be consolidated. (simplifyWhiteSpace)
- result.tqreplace('\n', TQString());
- result.tqreplace('\r', TQString());
+ result.replace('\n', TQString());
+ result.replace('\r', TQString());
result = result.stripWhiteSpace().simplifyWhiteSpace();
}
@@ -67,19 +67,19 @@ TQString SVGLangSpaceImpl::handleText(const TQString &data) const
{
// Spec: What to do here?
- // First, it will remove all newline characters (tqreplace)
+ // First, it will remove all newline characters (replace)
// Then it will convert all tab characters into space characters (simplifyWhiteSpace)
// Then, it will strip off all leading and trailing space characters (stripWhiteSpace)